# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.attachment_controller_api import AttachmentControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestAttachmentControllerApi(unittest.TestCase):
    """AttachmentControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.attachment_controller_api.AttachmentControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_upload_attachment(self):
        """Test case for upload_attachment

        Upload an attachment for sending using base64 file encoding. Returns an array whose first element is the ID of the uploaded attachment.  # noqa: E501
        """
        pass

    def test_upload_attachment_bytes(self):
        """Test case for upload_attachment_bytes

        Upload an attachment for sending using file byte stream input octet stream. Returns an array whose first element is the ID of the uploaded attachment.  # noqa: E501
        """
        pass

    def test_upload_multipart_form(self):
        """Test case for upload_multipart_form

        Upload an attachment for sending using a Multipart Form request. Returns an array whose first element is the ID of the uploaded attachment.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class UploadAttachmentOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base64_contents': 'str',
        'content_type': 'str',
        'filename': 'str'
    }

    attribute_map = {
        'base64_contents': 'base64Contents',
        'content_type': 'contentType',
        'filename': 'filename'
    }

    def __init__(self, base64_contents=None, content_type=None, filename=None, local_vars_configuration=None):  # noqa: E501
        """UploadAttachmentOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._base64_contents = None
        self._content_type = None
        self._filename = None
        self.discriminator = None

        if base64_contents is not None:
            self.base64_contents = base64_contents
        if content_type is not None:
            self.content_type = content_type
        if filename is not None:
            self.filename = filename

    @property
    def base64_contents(self):
        """Gets the base64_contents of this UploadAttachmentOptions.  # noqa: E501

        Base64 encoded string of file contents. Typically this means reading the bytes or string content of a file and then converting that to a base64 encoded string.  # noqa: E501

        :return: The base64_contents of this UploadAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._base64_contents

    @base64_contents.setter
    def base64_contents(self, base64_contents):
        """Sets the base64_contents of this UploadAttachmentOptions.

        Base64 encoded string of file contents. Typically this means reading the bytes or string content of a file and then converting that to a base64 encoded string.  # noqa: E501

        :param base64_contents: The base64_contents of this UploadAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._base64_contents = base64_contents

    @property
    def content_type(self):
        """Gets the content_type of this UploadAttachmentOptions.  # noqa: E501

        Optional contentType for file. For instance `application/pdf`  # noqa: E501

        :return: The content_type of this UploadAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this UploadAttachmentOptions.

        Optional contentType for file. For instance `application/pdf`  # noqa: E501

        :param content_type: The content_type of this UploadAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def filename(self):
        """Gets the filename of this UploadAttachmentOptions.  # noqa: E501

        Optional filename to save upload with. Will be the name that is shown in email clients  # noqa: E501

        :return: The filename of this UploadAttachmentOptions.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this UploadAttachmentOptions.

        Optional filename to save upload with. Will be the name that is shown in email clients  # noqa: E501

        :param filename: The filename of this UploadAttachmentOptions.  # noqa: E501
        :type: str
        """

        self._filename = filename

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadAttachmentOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UploadAttachmentOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PageEmailPreview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'list[EmailPreview]',
        'empty': 'bool',
        'first': 'bool',
        'last': 'bool',
        'number': 'int',
        'number_of_elements': 'int',
        'pageable': 'Pageable',
        'size': 'int',
        'sort': 'Sort',
        'total_elements': 'int',
        'total_pages': 'int'
    }

    attribute_map = {
        'content': 'content',
        'empty': 'empty',
        'first': 'first',
        'last': 'last',
        'number': 'number',
        'number_of_elements': 'numberOfElements',
        'pageable': 'pageable',
        'size': 'size',
        'sort': 'sort',
        'total_elements': 'totalElements',
        'total_pages': 'totalPages'
    }

    def __init__(self, content=None, empty=None, first=None, last=None, number=None, number_of_elements=None, pageable=None, size=None, sort=None, total_elements=None, total_pages=None, local_vars_configuration=None):  # noqa: E501
        """PageEmailPreview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._empty = None
        self._first = None
        self._last = None
        self._number = None
        self._number_of_elements = None
        self._pageable = None
        self._size = None
        self._sort = None
        self._total_elements = None
        self._total_pages = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if empty is not None:
            self.empty = empty
        if first is not None:
            self.first = first
        if last is not None:
            self.last = last
        if number is not None:
            self.number = number
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if pageable is not None:
            self.pageable = pageable
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if total_elements is not None:
            self.total_elements = total_elements
        if total_pages is not None:
            self.total_pages = total_pages

    @property
    def content(self):
        """Gets the content of this PageEmailPreview.  # noqa: E501


        :return: The content of this PageEmailPreview.  # noqa: E501
        :rtype: list[EmailPreview]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PageEmailPreview.


        :param content: The content of this PageEmailPreview.  # noqa: E501
        :type: list[EmailPreview]
        """

        self._content = content

    @property
    def empty(self):
        """Gets the empty of this PageEmailPreview.  # noqa: E501


        :return: The empty of this PageEmailPreview.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this PageEmailPreview.


        :param empty: The empty of this PageEmailPreview.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def first(self):
        """Gets the first of this PageEmailPreview.  # noqa: E501


        :return: The first of this PageEmailPreview.  # noqa: E501
        :rtype: bool
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this PageEmailPreview.


        :param first: The first of this PageEmailPreview.  # noqa: E501
        :type: bool
        """

        self._first = first

    @property
    def last(self):
        """Gets the last of this PageEmailPreview.  # noqa: E501


        :return: The last of this PageEmailPreview.  # noqa: E501
        :rtype: bool
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this PageEmailPreview.


        :param last: The last of this PageEmailPreview.  # noqa: E501
        :type: bool
        """

        self._last = last

    @property
    def number(self):
        """Gets the number of this PageEmailPreview.  # noqa: E501


        :return: The number of this PageEmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this PageEmailPreview.


        :param number: The number of this PageEmailPreview.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PageEmailPreview.  # noqa: E501


        :return: The number_of_elements of this PageEmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PageEmailPreview.


        :param number_of_elements: The number_of_elements of this PageEmailPreview.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def pageable(self):
        """Gets the pageable of this PageEmailPreview.  # noqa: E501


        :return: The pageable of this PageEmailPreview.  # noqa: E501
        :rtype: Pageable
        """
        return self._pageable

    @pageable.setter
    def pageable(self, pageable):
        """Sets the pageable of this PageEmailPreview.


        :param pageable: The pageable of this PageEmailPreview.  # noqa: E501
        :type: Pageable
        """

        self._pageable = pageable

    @property
    def size(self):
        """Gets the size of this PageEmailPreview.  # noqa: E501


        :return: The size of this PageEmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PageEmailPreview.


        :param size: The size of this PageEmailPreview.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this PageEmailPreview.  # noqa: E501


        :return: The sort of this PageEmailPreview.  # noqa: E501
        :rtype: Sort
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this PageEmailPreview.


        :param sort: The sort of this PageEmailPreview.  # noqa: E501
        :type: Sort
        """

        self._sort = sort

    @property
    def total_elements(self):
        """Gets the total_elements of this PageEmailPreview.  # noqa: E501


        :return: The total_elements of this PageEmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._total_elements

    @total_elements.setter
    def total_elements(self, total_elements):
        """Sets the total_elements of this PageEmailPreview.


        :param total_elements: The total_elements of this PageEmailPreview.  # noqa: E501
        :type: int
        """

        self._total_elements = total_elements

    @property
    def total_pages(self):
        """Gets the total_pages of this PageEmailPreview.  # noqa: E501


        :return: The total_pages of this PageEmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PageEmailPreview.


        :param total_pages: The total_pages of this PageEmailPreview.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageEmailPreview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageEmailPreview):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mailslurp_client.api.alias_controller_api import AliasControllerApi
from mailslurp_client.api.attachment_controller_api import AttachmentControllerApi
from mailslurp_client.api.bulk_actions_controller_api import BulkActionsControllerApi
from mailslurp_client.api.common_actions_controller_api import CommonActionsControllerApi
from mailslurp_client.api.contact_controller_api import ContactControllerApi
from mailslurp_client.api.domain_controller_api import DomainControllerApi
from mailslurp_client.api.email_controller_api import EmailControllerApi
from mailslurp_client.api.expired_controller_api import ExpiredControllerApi
from mailslurp_client.api.form_controller_api import FormControllerApi
from mailslurp_client.api.group_controller_api import GroupControllerApi
from mailslurp_client.api.inbox_controller_api import InboxControllerApi
from mailslurp_client.api.mail_server_controller_api import MailServerControllerApi
from mailslurp_client.api.sent_emails_controller_api import SentEmailsControllerApi
from mailslurp_client.api.template_controller_api import TemplateControllerApi
from mailslurp_client.api.wait_for_controller_api import WaitForControllerApi
from mailslurp_client.api.webhook_controller_api import WebhookControllerApi



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.alias_controller_api import AliasControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestAliasControllerApi(unittest.TestCase):
    """AliasControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.alias_controller_api.AliasControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_alias(self):
        """Test case for create_alias

        Create an email alias. Must be verified by clicking link inside verification email that will be sent to the address. Once verified the alias will be active.  # noqa: E501
        """
        pass

    def test_delete_alias(self):
        """Test case for delete_alias

        Delete an email alias  # noqa: E501
        """
        pass

    def test_get_alias(self):
        """Test case for get_alias

        Get an email alias  # noqa: E501
        """
        pass

    def test_get_alias_emails(self):
        """Test case for get_alias_emails

        Get emails for an alias  # noqa: E501
        """
        pass

    def test_get_alias_threads(self):
        """Test case for get_alias_threads

        Get threads created for an alias  # noqa: E501
        """
        pass

    def test_get_aliases(self):
        """Test case for get_aliases

        Get all email aliases you have created  # noqa: E501
        """
        pass

    def test_reply_to_alias_email(self):
        """Test case for reply_to_alias_email

        Reply to an email  # noqa: E501
        """
        pass

    def test_send_alias_email(self):
        """Test case for send_alias_email

        Send an email from an alias inbox  # noqa: E501
        """
        pass

    def test_update_alias(self):
        """Test case for update_alias

        Update an email alias  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
